@@ -1,5 +1,4 @@
 require 'gitsh/capturing_environment'
-require 'gitsh/string_runner'
 
 module Gitsh
   module Arguments
@@ -10,14 +9,20 @@ module Gitsh
 
       def value(env)
         capturing_env = CapturingEnvironment.new(env.clone)
-        StringRunner.run(env: capturing_env, command: command)
+        command.execute(capturing_env)
         strip_whitespace(capturing_env.captured_output)
       end
 
-      private
+      def ==(other)
+        other.is_a?(self.class) && command == other.command
+      end
+
+      protected
 
       attr_reader :command
 
+      private
+
       def strip_whitespace(output)
         output.
           sub(%r{\r?\n\Z}, '').
